from .program import program


if __name__ == "__main__":
    program(prog_name="livemark")
